/**
 * Main
 */

'use strict';

/**
 * Imports
 */

var { Services } = require('resource://gre/modules/Services.jsm');

var _ = require('sdk/l10n').get;
var pageMod = require('sdk/page-mod');
var self = require("sdk/self");

/**
 * Constants
 */

const BROWSER_NAME = 'Orfox';

/**
 * Variables
 */

var browserWindow = Services.wm.getMostRecentWindow('navigator:browser');
var browserWindowIdentifier = null;

/**
 * Public Functions
 */

exports.main = function () {

    pageMod.PageMod({
        include: 'chrome://tor-browser-settings/content/settings.html',
        contentScriptFile: self.data.url('content-scripts/settings.js'),
        contentScriptWhen: 'ready',
        onAttach: startListening
    });

    browserWindowIdentifier = browserWindow.NativeWindow.menu.add({
        name: _('settings_label', BROWSER_NAME),
        callback: function () {

            var tabBrowser = browserWindow.BrowserApp;

            tabBrowser.addTab('chrome://tor-browser-settings/content/settings.html', {
                selected: true,
                parentId: tabBrowser.selectedTab.id
            });

        }
    });
};

exports.onUnload = function () {

    // Clean up add-on state.
    browserWindow.NativeWindow.menu.remove(browserWindowIdentifier);
};

/**
 * Private Functions
 */

function startListening (worker) {

    worker.port.emit('worker:initialized', {

        l10n: {
            settings_label: _('settings_label', BROWSER_NAME),
            security_label: _('security_label'),
            standard_label: _('standard_label'),
            standard_description: _('standard_description', BROWSER_NAME),
            safer_label: _('safer_label'),
            safer_description: _('safer_description'),
            safer_list_label: _('safer_list_label'),
            safest_label: _('safest_label'),
            safest_description: _('safest_description'),
            safest_list_label: _('safest_list_label'),
            learn_more_label: _('learn_more_label')
        }
    });

    worker.port.on('preference:fetch', function (details) {

        // TODO Get the preference value using the Add-on SDK.
    });

    worker.port.on('preference:save', function (details) {

        // TODO Persist the preference using the Add-on SDK.
    });
}
